@@ -4,11 +4,7 @@ from fastapi import APIRouter, Depends, Query, Response, status
 from fastapi.param_functions import Body
 
 from contaxy import config
-from contaxy.api.dependencies import (
-    ComponentManager,
-    get_api_token,
-    get_component_manager,
-)
+from contaxy.api.dependencies import ComponentManager, get_component_manager
 from contaxy.schema import AccessLevel, CoreOperations, Project, ProjectInput, User
 from contaxy.schema.auth import USER_ID_PARAM
 from contaxy.schema.exceptions import (
@@ -20,6 +16,7 @@ from contaxy.schema.exceptions import (
 )
 from contaxy.schema.project import PROJECT_ID_PARAM, ProjectCreation
 from contaxy.schema.shared import MAX_DISPLAY_NAME_LENGTH, MIN_DISPLAY_NAME_LENGTH
+from contaxy.utils.auth_utils import get_api_token
 
 router = APIRouter(
     tags=["projects"],
